@@ -11,6 +11,7 @@
 #'
 #'
 #' @seealso \code{\link{embed_fonts}}
+#' @import grDevices
 #' @export
 loadfonts <- function(device = "pdf", quiet = FALSE) {
   fontdata <- fonttable()
@@ -153,6 +154,23 @@ loadfonts <- function(device = "pdf", quiet = FALSE) {
 #' @seealso \code{\link{loadfonts}}
 #' @export
 embed_fonts <- function(file, format, outfile = file, options = "") {
+  # This type detection code is necessary because of a bug in embedFonts where
+  # it does not correctly detect file type when there are space in the filename.
+  # https://bugs.r-project.org/bugzilla3/show_bug.cgi?id=15149
+  if (missing(format)) {
+    suffix <- gsub(".+[.]", "", file)
+    format <- switch(suffix, ps = , eps = "pswrite", pdf = "pdfwrite")
+  }
+
+  # To handle spaces, the input file can have quotes, but the output file
+  # shouldn't for some reason. We need to force evaluation here; if not, then
+  # lazy evaluation will result in outfile having quotes because of the change
+  # to file, below.
+  force(outfile)
+
+  # Put quotes around filenames so that spaces will work
+  file <- paste("'", file, "'", sep = "")
+
   embedFonts(file = file, format = format, outfile = outfile,
     options = paste(
       paste("-I", shQuote(fixpath_os(fontmap_path())), sep = ""),
